#
# modbuild.pm - openisr-config module to build kernel modules with DKMS
#
# Copyright (C) 2007-2008 Carnegie Mellon University
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of version 2 of the GNU General Public License as published
# by the Free Software Foundation.  A copy of the GNU General Public License
# should have been distributed along with this program in the file
# LICENSE.GPL.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#

use strict;
use warnings;
use POSIX;

sub build {
	my $need_build = 1;
	my $need_install = 1;

	status "Checking status of kernel modules...";

	open FD, "-|", "dkms status"
		or fail "Couldn't get DKMS status";
	while (<FD>) {
		next if !/^openisr-client, ([^,]+), ([^,]+),/;
		next if $1 ne VERSION;
		next if $2 ne (uname)[2];
		if (/installed/) {
			$need_build = 0;
			$need_install = 0;
		} elsif (/built/) {
			$need_build = 0;
		}
		last;
	}
	close FD;

	if ($need_build) {
		status "Building modules with DKMS...";
		system("dkms build -m openisr-client -v " . VERSION) == 0
			or fail "DKMS build failed.";
	} else {
		status "Modules already built with DKMS.";
	}

	if ($need_install) {
		status "Installing modules with DKMS...";
		system("dkms install -m openisr-client -v " . VERSION) == 0
			or fail "DKMS install failed.";
	} else {
		status "Modules already installed with DKMS.";
	}
}

1;
